NXSConfigServer Tango Class Command CreateConfiguration

Command CreateConfiguration :

Creates the NDTS configuration script from the given components. The result is strored in XMLString

CreateConfiguration Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of component names
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..